==> zio-aws-route53recoverycontrolconfig_2.13-7.21.15.4-sources.jar: zio/aws/route53recoverycontrolconfig/model/GatingRule.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __stringMin12Max12PatternD12,
  __integer,
  __stringMin1Max64PatternS,
  __stringMin1Max256PatternAZaZ09
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class GatingRule(
    controlPanelArn: __stringMin1Max256PatternAZaZ09,
    gatingControls: Iterable[__stringMin1Max256PatternAZaZ09],
    name: __stringMin1Max64PatternS,
    ruleConfig: zio.aws.route53recoverycontrolconfig.model.RuleConfig,
    safetyRuleArn: __stringMin1Max256PatternAZaZ09,
    status: zio.aws.route53recoverycontrolconfig.model.Status,
    targetControls: Iterable[__stringMin1Max256PatternAZaZ09],
    waitPeriodMs: __integer,
    owner: Optional[__stringMin12Max12PatternD12] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.GatingRule = {
    import GatingRule.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.GatingRule
      .builder()
      .controlPanelArn(controlPanelArn: java.lang.String)
      .gatingControls(gatingControls.map { item =>
        item: java.lang.String
      }.asJavaCollection)
      .name(name: java.lang.String)
      .ruleConfig(ruleConfig.buildAwsValue())
      .safetyRuleArn(safetyRuleArn: java.lang.String)
      .status(status.unwrap)
      .targetControls(targetControls.map { item =>
        item: java.lang.String
      }.asJavaCollection)
      .waitPeriodMs(waitPeriodMs: Integer)
      .optionallyWith(owner.map(value => value: java.lang.String))(_.owner)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.GatingRule.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.GatingRule.wrap(buildAwsValue())
}
object GatingRule {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.GatingRule
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53recoverycontrolconfig.model.GatingRule =
      zio.aws.route53recoverycontrolconfig.model.GatingRule(
        controlPanelArn,
        gatingControls,
        name,
        ruleConfig.asEditable,
        safetyRuleArn,
        status,
        targetControls,
        waitPeriodMs,
        owner.map(value => value)
      )
    def controlPanelArn: __stringMin1Max256PatternAZaZ09
    def gatingControls: List[__stringMin1Max256PatternAZaZ09]
    def name: __stringMin1Max64PatternS
    def ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    def safetyRuleArn: __stringMin1Max256PatternAZaZ09
    def status: zio.aws.route53recoverycontrolconfig.model.Status
    def targetControls: List[__stringMin1Max256PatternAZaZ09]
    def waitPeriodMs: __integer
    def owner: Optional[__stringMin12Max12PatternD12]
    def getControlPanelArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(controlPanelArn)
    def getGatingControls
        : ZIO[Any, Nothing, List[__stringMin1Max256PatternAZaZ09]] =
      ZIO.succeed(gatingControls)
    def getName: ZIO[Any, Nothing, __stringMin1Max64PatternS] =
      ZIO.succeed(name)
    def getRuleConfig: ZIO[
      Any,
      Nothing,
      zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    ] = ZIO.succeed(ruleConfig)
    def getSafetyRuleArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(safetyRuleArn)
    def getStatus
        : ZIO[Any, Nothing, zio.aws.route53recoverycontrolconfig.model.Status] =
      ZIO.succeed(status)
    def getTargetControls
        : ZIO[Any, Nothing, List[__stringMin1Max256PatternAZaZ09]] =
      ZIO.succeed(targetControls)
    def getWaitPeriodMs: ZIO[Any, Nothing, __integer] =
      ZIO.succeed(waitPeriodMs)
    def getOwner: ZIO[Any, AwsError, __stringMin12Max12PatternD12] =
      AwsError.unwrapOptionField("owner", owner)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.GatingRule
  ) extends zio.aws.route53recoverycontrolconfig.model.GatingRule.ReadOnly {
    override val controlPanelArn: __stringMin1Max256PatternAZaZ09 =
      impl.controlPanelArn(): __stringMin1Max256PatternAZaZ09
    override val gatingControls: List[__stringMin1Max256PatternAZaZ09] = impl
      .gatingControls()
      .asScala
      .map { item =>
        item: __stringMin1Max256PatternAZaZ09
      }
      .toList
    override val name: __stringMin1Max64PatternS =
      impl.name(): __stringMin1Max64PatternS
    override val ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly =
      zio.aws.route53recoverycontrolconfig.model.RuleConfig
        .wrap(impl.ruleConfig())
    override val safetyRuleArn: __stringMin1Max256PatternAZaZ09 =
      impl.safetyRuleArn(): __stringMin1Max256PatternAZaZ09
    override val status: zio.aws.route53recoverycontrolconfig.model.Status =
      zio.aws.route53recoverycontrolconfig.model.Status.wrap(impl.status())
    override val targetControls: List[__stringMin1Max256PatternAZaZ09] = impl
      .targetControls()
      .asScala
      .map { item =>
        item: __stringMin1Max256PatternAZaZ09
      }
      .toList
    override val waitPeriodMs: __integer = impl.waitPeriodMs(): __integer
    override val owner: Optional[__stringMin12Max12PatternD12] =
      zio.aws.core.internal
        .optionalFromNullable(impl.owner())
        .map(value => value: __stringMin12Max12PatternD12)
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.GatingRule
  ): zio.aws.route53recoverycontrolconfig.model.GatingRule.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_3-5.17.130.3-sources.jar: zio/aws/route53recoverycontrolconfig/model/GatingRule.scala <==
package zio.aws.route53recoverycontrolconfig.model
import java.lang.Integer
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __integer,
  __stringMin1Max64PatternS,
  __stringMin1Max256PatternAZaZ09
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GatingRule(
    controlPanelArn: __stringMin1Max256PatternAZaZ09,
    gatingControls: Iterable[__stringMin1Max256PatternAZaZ09],
    name: __stringMin1Max64PatternS,
    ruleConfig: zio.aws.route53recoverycontrolconfig.model.RuleConfig,
    safetyRuleArn: __stringMin1Max256PatternAZaZ09,
    status: zio.aws.route53recoverycontrolconfig.model.Status,
    targetControls: Iterable[__stringMin1Max256PatternAZaZ09],
    waitPeriodMs: __integer
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.GatingRule = {
    import GatingRule.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.GatingRule
      .builder()
      .controlPanelArn(
        __stringMin1Max256PatternAZaZ09.unwrap(
          controlPanelArn
        ): java.lang.String
      )
      .gatingControls(gatingControls.map { item =>
        __stringMin1Max256PatternAZaZ09.unwrap(item): java.lang.String
      }.asJavaCollection)
      .name(__stringMin1Max64PatternS.unwrap(name): java.lang.String)
      .ruleConfig(ruleConfig.buildAwsValue())
      .safetyRuleArn(
        __stringMin1Max256PatternAZaZ09.unwrap(safetyRuleArn): java.lang.String
      )
      .status(status.unwrap)
      .targetControls(targetControls.map { item =>
        __stringMin1Max256PatternAZaZ09.unwrap(item): java.lang.String
      }.asJavaCollection)
      .waitPeriodMs(__integer.unwrap(waitPeriodMs): Integer)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.GatingRule.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.GatingRule.wrap(buildAwsValue())
}
object GatingRule {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.GatingRule
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53recoverycontrolconfig.model.GatingRule =
      zio.aws.route53recoverycontrolconfig.model.GatingRule(
        controlPanelArn,
        gatingControls,
        name,
        ruleConfig.asEditable,
        safetyRuleArn,
        status,
        targetControls,
        waitPeriodMs
      )
    def controlPanelArn: __stringMin1Max256PatternAZaZ09
    def gatingControls: List[__stringMin1Max256PatternAZaZ09]
    def name: __stringMin1Max64PatternS
    def ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    def safetyRuleArn: __stringMin1Max256PatternAZaZ09
    def status: zio.aws.route53recoverycontrolconfig.model.Status
    def targetControls: List[__stringMin1Max256PatternAZaZ09]
    def waitPeriodMs: __integer
    def getControlPanelArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(controlPanelArn)
    def getGatingControls
        : ZIO[Any, Nothing, List[__stringMin1Max256PatternAZaZ09]] =
      ZIO.succeed(gatingControls)
    def getName: ZIO[Any, Nothing, __stringMin1Max64PatternS] =
      ZIO.succeed(name)
    def getRuleConfig: ZIO[
      Any,
      Nothing,
      zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    ] = ZIO.succeed(ruleConfig)
    def getSafetyRuleArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(safetyRuleArn)
    def getStatus
        : ZIO[Any, Nothing, zio.aws.route53recoverycontrolconfig.model.Status] =
      ZIO.succeed(status)
    def getTargetControls
        : ZIO[Any, Nothing, List[__stringMin1Max256PatternAZaZ09]] =
      ZIO.succeed(targetControls)
    def getWaitPeriodMs: ZIO[Any, Nothing, __integer] =
      ZIO.succeed(waitPeriodMs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.GatingRule
  ) extends zio.aws.route53recoverycontrolconfig.model.GatingRule.ReadOnly {
    override val controlPanelArn: __stringMin1Max256PatternAZaZ09 =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__stringMin1Max256PatternAZaZ09(impl.controlPanelArn())
    override val gatingControls: List[__stringMin1Max256PatternAZaZ09] = impl
      .gatingControls()
      .asScala
      .map { item =>
        zio.aws.route53recoverycontrolconfig.model.primitives
          .__stringMin1Max256PatternAZaZ09(item)
      }
      .toList
    override val name: __stringMin1Max64PatternS =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__stringMin1Max64PatternS(impl.name())
    override val ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly =
      zio.aws.route53recoverycontrolconfig.model.RuleConfig
        .wrap(impl.ruleConfig())
    override val safetyRuleArn: __stringMin1Max256PatternAZaZ09 =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__stringMin1Max256PatternAZaZ09(impl.safetyRuleArn())
    override val status: zio.aws.route53recoverycontrolconfig.model.Status =
      zio.aws.route53recoverycontrolconfig.model.Status.wrap(impl.status())
    override val targetControls: List[__stringMin1Max256PatternAZaZ09] = impl
      .targetControls()
      .asScala
      .map { item =>
        zio.aws.route53recoverycontrolconfig.model.primitives
          .__stringMin1Max256PatternAZaZ09(item)
      }
      .toList
    override val waitPeriodMs: __integer =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__integer(impl.waitPeriodMs())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.GatingRule
  ): zio.aws.route53recoverycontrolconfig.model.GatingRule.ReadOnly =
    new Wrapper(impl)
}
